import Seat from './Seat';
import styles from './styles.module.css';

const BookingWrapper = ({
  selectedSeats,
  seatData,
  currentSeats,
  onSeatAdd,
  onSeatRemove
}) => {
  const handleSeatClick = (row, seat, status) => {
    if (status == 'current-selected') {
      onSeatRemove(row, seat);
    } else {
      onSeatAdd(row, seat);
    }
  };

  return (
    <div className={styles['booking-wrapper']}>
      <div className={styles['theatre']}>
        {seatData?.map((row, row_index) => (
          <div key={`row-${row_index}`} className={styles['seat-row']}>
            {row?.map((seat, column_index) => {
              if (seat === '*') {
                return (
                  <div
                    key={`gap-${row_index}-${column_index}`}
                    className={styles['seat-gap']}
                  />
                );
              }

              const seatKey = `${row_index + 1}-${seat}`;

              let seatClass = '';
              const foundInCurrentSeats = currentSeats?.find(
                (e) => e.row === row_index + 1 && e.seat === seat
              );
              const foundInSelectedSeats = selectedSeats?.some(
                (e) => e.row === row_index + 1 && e.seat === seat
              );

              if (foundInCurrentSeats) {
                seatClass = 'current-selected';
              } else if (foundInSelectedSeats) {
                seatClass = 'selected-by-other';
              }

              return (
                <Seat
                  key={seatKey}
                  status={seatClass}
                  id={seat}
                  onClick={() =>
                    handleSeatClick(row_index + 1, seat, seatClass)
                  }
                />
              );
            })}
          </div>
        ))}
      </div>
    </div>
  );
};

export default BookingWrapper;
